/*
 * Copyright 1994, 1995 Vectaport Inc., Cartoactive Systems
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 */

/* Class wrapper for vpf coverage object */

#ifndef vpfcov_h
#define vpfcov_h

#include <Map/mapcov.h>
#include <Vpf/vpf.h>

class VpfLibrary;
class VpfFeatureClass;

class VpfCoverage : public MapCoverage {
public:
    VpfCoverage (VpfLibrary*, const char* name);
    virtual ~VpfCoverage ();

    virtual const char* path() const;
    VpfLibrary* library() const { return (VpfLibrary*)_library; }
    virtual void library(VpfLibrary* lib);

    VpfFeatureClass* feature_class(int fclsnum) const;
    VpfFeatureClass* feature_class(const char*) const;

    virtual const char* description() const;

    int topology_level() const;
    char* int_value_description(const char* colname, int val);
    char* char_value_description(const char* colname, char* val);

    void print() const;
    void dump_fcs() const;

    vpf_table_type edgetable(char*);
    vpf_table_type facetable(char*);
protected:
    virtual char** feature_class_names (int& nfcls) const;
    virtual MapFeatureClass* make_feature_class(const char* name);

    virtual void load_edge_table(char*);
    virtual void load_node_table();
    virtual void load_face_table(char*);

protected:
    char* _desc;
    vpf_table_type _intvdt;
    vpf_table_type _charvdt;
    vpf_table_type _edgetable;
    vpf_table_type _facetable;
};

int pretty_dump_table(char*, FILE*);
#endif /* defined(vpf_h) */
